CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
77 lines
2.1 KiB
C++
77 lines
2.1 KiB
C++
/* This testcase is part of GDB, the GNU debugger.
|
|
|
|
Copyright (C) 2026 Free Software Foundation, Inc.
|
|
Copyright (C) 2026 Advanced Micro Devices, Inc. All rights reserved.
|
|
|
|
This program is free software; you can redistribute it and/or modify
|
|
it under the terms of the GNU General Public License as published by
|
|
the Free Software Foundation; either version 3 of the License, or
|
|
(at your option) any later version.
|
|
|
|
This program is distributed in the hope that it will be useful,
|
|
but WITHOUT ANY WARRANTY; without even the implied warranty of
|
|
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
|
|
GNU General Public License for more details.
|
|
|
|
You should have received a copy of the GNU General Public License
|
|
along with this program. If not, see <http://www.gnu.org/licenses/>. */
|
|
|
|
#include <hip/hip_runtime.h>
|
|
#include <cassert>
|
|
|
|
#include "rocm-test-utils.h"
|
|
|
|
__global__ void
|
|
kern ()
|
|
{
|
|
int lane = threadIdx.x;
|
|
volatile int local = lane;
|
|
alignas (4) volatile unsigned char arr[5] = {0x11, 0x22, 0x33, 0x44, 0x55};
|
|
volatile int *gen_local_addr = &local;
|
|
/* A generic address to a 32-bit integer that is straddled over
|
|
two DWORDS in the backing memory. */
|
|
volatile uint32_t *gen_arr1_addr = (uint32_t *) &arr[1];
|
|
|
|
/* Break here 1; debugger's actions:
|
|
- Switch to lane 11.
|
|
- Run some checks.
|
|
- Change "local" to 1337. */
|
|
NOP (1);
|
|
|
|
if (lane == 11)
|
|
{
|
|
assert (local == 1337);
|
|
/* Break here 2: If hit, the assert must have gone smoothly. */
|
|
NOP (2);
|
|
}
|
|
|
|
/* Break here 3; debugger's actions:
|
|
- Check if still in lane 11.
|
|
- Run some other checks.
|
|
- Change "arr[1..4]" to 0x87654321. */
|
|
NOP (3);
|
|
|
|
if (lane == 11)
|
|
{
|
|
assert (*((uint32_t *) &arr[1]) == 0x87654321);
|
|
/* Break here 4: If hit, the assert must have gone smoothly. */
|
|
NOP (4);
|
|
}
|
|
}
|
|
|
|
int
|
|
main()
|
|
{
|
|
int device_id;
|
|
hipDeviceProp_t props;
|
|
CHECK (hipGetDevice (&device_id));
|
|
CHECK (hipGetDeviceProperties (&props, device_id));
|
|
|
|
/* There must be at least 12 lanes. */
|
|
assert (props.warpSize > 11);
|
|
|
|
kern<<<1, props.warpSize>>> ();
|
|
|
|
return hipDeviceSynchronize () != hipSuccess;
|
|
}
|